Clojure wrapper for the Google Keep API (v1).
Provides idiomatic Clojure functions for managing notes, note permissions, and attachment downloads.
Auth: use csl/scoped-delegated-credentials or csl/user-credentials with the appropriate scope:
The Keep API is enterprise-only as of 2025 — consumers must be on a Workspace plan that exposes the Keep API.
list-notes returns {:data [...] :next-page-token "..."}. :next-page-token is absent when there are no further pages. Other functions return {:data ...} on success or {:error ...} on failure.
Clojure wrapper for the Google Keep API (v1).
Provides idiomatic Clojure functions for managing notes, note permissions,
and attachment downloads.
Auth: use csl/scoped-delegated-credentials or csl/user-credentials with
the appropriate scope:
- KeepScopes/KEEP (full read/write)
- KeepScopes/KEEP_READONLY (read-only)
The Keep API is enterprise-only as of 2025 — consumers must be on a
Workspace plan that exposes the Keep API.
list-notes returns {:data [...] :next-page-token "..."}. :next-page-token
is absent when there are no further pages. Other functions return
{:data ...} on success or {:error ...} on failure.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |